@@ -1,3 +1,13 @@
+/* libTiMidity is licensed under the terms of the GNU Lesser General
+ * Public License: see COPYING for details.
+ *
+ * Note that the included TiMidity source, based on timidity-0.2i, was
+ * originally licensed under the GPL, but the author extended it so it
+ * can also be used separately under the GNU LGPL or the Perl Artistic
+ * License: see the notice by Tuukka Toivonen as it appears on the web
+ * at http://ieee.uwaterloo.ca/sca/www.cgs.fi/tt/timidity/ .
+ */
+
 /* timi_endian.h -- endianness detection
  * Copyright (C) 2007-2016  O.Sezer <sezero@users.sourceforge.net>
  *
@@ -48,6 +58,8 @@
 #  include <machine/endian.h>
 # elif defined(__OS2__) && defined(__WATCOMC__)
 #  include <machine/endian.h>
+# elif defined(__MORPHOS__)
+#  include <machine/endian.h>
 # elif defined(__amigaos__) && defined(__NEWLIB__)
 #  include <machine/endian.h>
 # elif defined(__amigaos__) && defined(__CLIB2__)
@@ -171,10 +183,10 @@
 /* assumptions based on OS and/or architecture macros.
  * proceed carefully: many of these are bi-endian CPUs.
  */
-# if defined (__ppc__) || defined(__POWERPC__) || defined(__PPC__)
+# if defined(__ppc__) || defined(__powerpc__) || defined(__POWERPC__) || defined(__PPC__)
 #  define BYTE_ORDER BIG_ENDIAN
 
-# elif (defined(__alpha__) || defined(__alpha))
+# elif defined(__alpha__) || defined(__alpha)
 #  define BYTE_ORDER LITTLE_ENDIAN
 
 # elif defined(__mips__) || defined(__MIPS__)
