@@ -124,6 +124,12 @@ extern sint32 XCHG_LONG (sint32);
 #endif
 #endif
 
+#ifndef __VBCC__
+#define TIMI_UNUSED(x) (void)(x)
+#else
+#define TIMI_UNUSED(x) /* vbcc emits an annoying warning for (void)(x) */
+#endif
+
 
 #define MID_VIBRATO_SAMPLE_INCREMENTS 32
 
@@ -220,7 +226,7 @@ struct _MidEventList
 
 struct _MidSong
 {
-  int oom;/* malloc failed */
+  int oom; /* malloc() failed */
   int playing;
   sint32 rate;
   sint32 encoding;
@@ -229,7 +235,6 @@ struct _MidSong
   sint32 amplification;
   MidToneBank *tonebank[128];
   MidToneBank *drumset[128];
-  FILE *ifp; /* patch file pointer used by the instrument loader */
   MidInstrument *default_instrument;
   int default_program;
   void (*write) (void *dp, sint32 *lp, sint32 c);
